summaryrefslogtreecommitdiffstats
path: root/part/kxe_viewattributes.h
diff options
context:
space:
mode:
Diffstat (limited to 'part/kxe_viewattributes.h')
-rw-r--r--part/kxe_viewattributes.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/part/kxe_viewattributes.h b/part/kxe_viewattributes.h
index c314c56..9b92d60 100644
--- a/part/kxe_viewattributes.h
+++ b/part/kxe_viewattributes.h
@@ -18,22 +18,22 @@
#ifndef KXE_VIEWATTRIBUTES_H
#define KXE_VIEWATTRIBUTES_H
-#include <qtable.h>
-#include <qdom.h>
+#include <tqtable.h>
+#include <tqdom.h>
/**
* @author The KXMLEditor Team
*/
-class KXE_ViewAttributes : public QTable
+class KXE_ViewAttributes : public TQTable
{
Q_OBJECT
public:
- KXE_ViewAttributes( QWidget * pParent = 0, const char * pszName = 0 );
+ KXE_ViewAttributes( TQWidget * pParent = 0, const char * pszName = 0 );
/** Returns a pointer to the currently selected attribute or a null pointer. */
- QDomAttr getSelectedAttribute() const;
+ TQDomAttr getSelectedAttribute() const;
/** Changes the behaviour of this view to readonly or readwrite. */
void setReadWrite( bool fReadWrite );
@@ -41,17 +41,17 @@ class KXE_ViewAttributes : public QTable
public slots:
/** Changes/Rebuilds the whole table according to the given element's attributes. */
- void slotChange( const QDomElement & element );
+ void slotChange( const TQDomElement & element );
protected:
/** the currently selected node */
- QDomElement m_domElement;
+ TQDomElement m_domElement;
protected slots:
- /** Called, when a context menu was requested (connected to @ref QTable::contextMenuRequested). */
- void slotContextMenuRequested( int nRow, int nCol, const QPoint & pos );
+ /** Called, when a context menu was requested (connected to @ref TQTable::contextMenuRequested). */
+ void slotContextMenuRequested( int nRow, int nCol, const TQPoint & pos );
/** Called, when an item was changed via inplace editing. */
void slotItemRenamedInplace( int nRow, int nCol );
@@ -59,13 +59,13 @@ class KXE_ViewAttributes : public QTable
signals:
/** Emitted, when a context menu is requested */
- void sigContextMenuRequested( const QString & szMenuName, const QPoint & pos );
+ void sigContextMenuRequested( const TQString & szMenuName, const TQPoint & pos );
/** Emitted, when an attributes value was renamed via inplace editing. */
- void sigAttributeNameChangedInplace( const QDomAttr &, const QString );
+ void sigAttributeNameChangedInplace( const TQDomAttr &, const TQString );
/** Emitted, when an attributes value was renamed via inplace editing. */
- void sigAttributeValueChangedInplace( const QDomAttr &, const QString );
+ void sigAttributeValueChangedInplace( const TQDomAttr &, const TQString );
};
#endif